@@ -15,8 +15,15 @@ from keypartx.basemodes.avn_base import nlp
 
 
 ## -- avnn edges-- ##
-def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL):
-    
+def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False):
+    """
+    include_otherEdge: greedy edges of the unmatched adj, verb, noun 
+    only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
+    nounDEL : nouns to be removed 
+    adjDEL : adjective to be removed 
+    facility: additional noun for the missing in the include_otherEdge class, e.g. I recommend! So pretty! 
+    faciNN: add facility noun to NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
+    """
     time_start = time.time()
     all_adjV2N_edges = []
     allNNedges = [] # noun to noun is the noun in adjV2N 
@@ -50,7 +57,7 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
             line1 = re.sub(' +', ' ', line1).strip() #remove extra space whitespace 
             print('line1:', line1)
             if by_review:
-                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL)
+                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN)
                 #all_adjV2N_edges, allNNedges, all_adjV2N_edges_drop, all_new_nodes, all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs
                 allNNedges.extend(allNNedges0)
                 all_adjV2N_edges.extend(all_adjV2N_edges0)
@@ -64,7 +71,7 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
                     #print(sent)
                     if len(sent.text.split())>2: # minimal 2 words
                         print('sentence' + str(ib),sent.text)
-                        all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(sent.text,verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound)
+                        all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(sent.text,verbose_text = verbose_text,verbose = False,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN)
                         
                         allNNedges.extend(allNNedges0)
                         all_adjV2N_edges.extend(all_adjV2N_edges0)
